'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var router = require('next/router');
var queryString = require('query-string');

/**
 * During contextual routing browser URL will be controlled by Next Router's "as" prop
 * while the page actually rendered is defined by Next Router's "href" prop.
 *
 * During contextual navigation Next Router's behaves as follows:
 * router.asPath:   /item/3               reflects current URL and updates at each page change
 * router.pathname: /search/[terms]       stay the same as long as initial page doesn't change
 * router.query:    {"terms": "foo-bar"}  same as above
 *
 * {Object} result
 * {string} result.returnHref       path where contextual routing started from
 * {string} result.contextualHref   href value to needed to start a contextual routing session (along with an "as" prop)
 * @returns result
 */

function useContextualRouting() {
  var router$1 = router.useRouter();

  var _useState = react.useState(router$1.asPath),
      returnHref = _useState[0],
      setReturnHref = _useState[1]; // @NOTE JSON.stringify might be replaced with any hashing solution


  var querySignature = JSON.stringify(router$1.query);
  var queryString$1 = react.useMemo(function () {
    var queryAsString = queryString.stringify(router$1.query);
    return queryAsString ? "?".concat(queryAsString) : '';
  }, [querySignature]);
  var contextualHref = router$1.pathname + queryString$1;
  react.useEffect(function () {
    setReturnHref(router$1.asPath);
  }, [querySignature]);
  return {
    returnHref: returnHref,
    contextualHref: contextualHref
  };
}

exports.useContextualRouting = useContextualRouting;
